/*

- preferences

  - general

    - openInTab

    - username

    - friendsList

  - matches

    - league

      - get

      - within

      - withinHours

    - friends

      - get

      - within

      - withinHours

  - notification

    - sound

    - soundOnlyOpened

    - flash

    - slider

*/



LiveFox.Preferences = function() {

  service = null;

}



LiveFox.Preferences.root = function() {

  this.general = new LiveFox.Preferences.general();

  this.matches = new LiveFox.Preferences.matches();

  this.notification = new LiveFox.Preferences.notification();

};



LiveFox.Preferences.general = function() {

  this.openInTab = true;

  this.friendsList="";

  this.username = "";

};



LiveFox.Preferences.matches = function(l, f) {

  this.league = new LiveFox.Preferences.matches.league();

  this.friends = new LiveFox.Preferences.matches.friends();

}



LiveFox.Preferences.matches.league = function() {

  this.get = true;

  this.within = true;

  this.withinHours = 24;

}



LiveFox.Preferences.matches.friends = function() {

  this.get = true;

  this.within = true;

  this.withinHours = 24;

}



LiveFox.Preferences.notification = function() {

  this.sound = false;

  this.soundOnlyOpened = true;

  this.flash = true;

  this.slider = true;

}



LiveFox.Preferences.start = function() {

  try {



    if (!LiveFox.Preferences.service) {

      LiveFox.Preferences.service = Components.classes["@mozilla.org/preferences-service;1"].

        getService(Components.interfaces.nsIPrefBranch);

    }

  } catch(e) {

    LiveFox.Log.warn("Cannot start preferences: " + e);

  }

    

}



LiveFox.Preferences.get = function() {

  LiveFox.Preferences.start();

  var prefs = new LiveFox.Preferences.root(); 

  LiveFox.Preferences.load(prefs);

  return prefs;

}



LiveFox.Preferences.load = function(prefs) {

    LiveFox.Preferences.start();

    var service = LiveFox.Preferences.service;

    

    try {

      prefs.general.openInTab = service.getBoolPref("livefox.openInTab");

      prefs.general.friendsList = LiveFox.Preferences.friends.get();

    

      prefs.matches.league.get = service.getBoolPref("livefox.matches.league.get");

      prefs.matches.league.within = service.getBoolPref("livefox.matches.league.within");

      prefs.matches.league.withinHours = service.getIntPref("livefox.matches.league.withinHours");

    

      prefs.matches.friends.get = service.getBoolPref("livefox.matches.friends.get");

      prefs.matches.friends.within = service.getBoolPref("livefox.matches.friends.within");

      prefs.matches.friends.withinHours = service.getIntPref("livefox.matches.friends.withinHours");

  

      prefs.notification.sound = service.getBoolPref("livefox.notification.sound");

      prefs.notification.soundOnlyOpened = service.getBoolPref("livefox.notification.soundOnlyOpened");

      prefs.notification.flash = service.getBoolPref("livefox.notification.flash");

      prefs.notification.slider = service.getBoolPref("livefox.notification.slider");

    } catch(e) {

      LiveFox.Log.warn("Cannot load preferences: " + e);

    }



    try {

      prefs.general.username = LiveFox.Preferences.username.get();

    } catch(e) {

      LiveFox.Log.warn("Cannot load username: " + e);

    }

}



LiveFox.Preferences.save = function(prefs) {

  try {

    LiveFox.Log.trace("saving preferences...");

    LiveFox.Preferences.start();

    var s = LiveFox.Preferences.service;

    

    s.setBoolPref("livefox.openInTab", prefs.general.openInTab);

    LiveFox.Preferences.friends.save(prefs.general.friendsList);

    

    s.setBoolPref("livefox.matches.league.get",prefs.matches.league.get);

    s.setBoolPref("livefox.matches.league.within",prefs.matches.league.within);

    s.setIntPref("livefox.matches.league.withinHours",prefs.matches.league.withinHours);

  

    s.setBoolPref("livefox.matches.friends.get",prefs.matches.friends.get);

    s.setBoolPref("livefox.matches.friends.within",prefs.matches.friends.within);

    s.setIntPref("livefox.matches.friends.withinHours",prefs.matches.friends.withinHours);



    s.setBoolPref("livefox.notification.sound",prefs.notification.sound);

    s.setBoolPref("livefox.notification.soundOnlyOpened",prefs.notification.soundOnlyOpened);

    s.setBoolPref("livefox.notification.flash",prefs.notification.flash);

    s.setBoolPref("livefox.notification.slider",prefs.notification.slider);

    

    LiveFox.Preferences.username.save(prefs.general.username);

    LiveFox.Log.trace("...done");



  } catch(e) {

    LiveFox.Log.warn("Cannot save preferences: " + e);

  }

}







LiveFox.Preferences.friends = {

  get: function() {

    var friends="";

    try {

      LiveFox.Preferences.start();

      var service = LiveFox.Preferences.service;

      friends = service.getCharPref("livefox.friendsList");

    } catch(e) {

      LiveFox.Log.warn("cannot load friends. " + e);

    }

    return friends;

  

  },

  save: function(friends) {

    try {

      LiveFox.Preferences.start();

      var service = LiveFox.Preferences.service;

      service.setCharPref("livefox.friendsList", friends);

    } catch(e) {

      LiveFox.Log.warn("cannot save friends. " + e);

    }

  }

}



LiveFox.Preferences.username = {

  get: function() {

    var username="";

    try {

      LiveFox.Preferences.start();

      var service = LiveFox.Preferences.service;

      username = service.getCharPref("livefox.username");

    } catch(e) {

      LiveFox.Log.warn("cannot load username. " + e);

    }

    return username;

  

  },

  save: function(username) {

    try {

      LiveFox.Preferences.start();

      var service = LiveFox.Preferences.service;

      service.setCharPref("livefox.username", username);

    } catch(e) {

      LiveFox.Log.warn("cannot save username. " + e);

    }

  }

}



LiveFox.Preferences.password = {

  get: function() {

    var outHost = new Object();

    var outUser = new Object();

    var outPass = new Object();



    try {

      var passwordmanager = Components.classes["@mozilla.org/passwordmanager;1"]

                      .createInstance(Components.interfaces.nsIPasswordManagerInternal);

      passwordmanager.findPasswordEntry("LiveFox.xpi", "username", "", outHost, outUser, outPass);

    } catch(e) {

      LiveFox.Log.warn("cannot get security code. " + e);

    }

    return outPass.value;

  },

  save: function(password) {

    try {

      var passwordManager = Components.classes["@mozilla.org/passwordmanager;1"]

          .createInstance(Components.interfaces.nsIPasswordManager);

      passwordManager.addUser("LiveFox.xpi","username", password);

    } catch(e) {

      LiveFox.Log.warn("cannot save security code. " + e);

    }

      

  }

}









